

set -ex



test -e $PREFIX/lib/libcryptominisat5.so.5.6
cryptominisat5_simple --zero-exit-status <unsat.cnf
cryptominisat5_simple --zero-exit-status <sat.cnf
cryptominisat5_simple <unsat.cnf | grep UNSATISFIABLE
cryptominisat5_simple <sat.cnf   | grep SATISFIABLE
exit 0
